@@ -264,13 +264,13 @@ class SqsToLambdaProps:
         :summary: The properties for the SqsToLambda class.
         '''
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = FunctionProps(**lambda_function_props)
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         if isinstance(queue_props, dict):
-            queue_props = QueueProps(**queue_props)
+            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
         if isinstance(sqs_event_source_props, dict):
-            sqs_event_source_props = SqsEventSourceProps(**sqs_event_source_props)
+            sqs_event_source_props = aws_cdk.aws_lambda_event_sources.SqsEventSourceProps(**sqs_event_source_props)
         if __debug__:
             type_hints = typing.get_type_hints(SqsToLambdaProps.__init__)
             check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
